# Code for Figure 2 & Figure S4 in
# Potential pension fund losses should not deter high-income countries from bold climate action
# https://doi.org/10.1016/j.joule.2023.05.023
# by Gregor Semieniuk, Lucas Chancel and Eulalie Saïsset

# load packages
library(tidyverse)
library(viridis)
options(scipen=999)

# set your working directory
setwd( "YOUR DIRECTORY" )

# load data
dd <- read_csv("figure2_data.csv")

# create losses as share of net wealth for various loss scenarios (ben, med, quo, sev) and various wealth elasticities (0.8 to 1.2 with 'nondep_share' the default elasticity of 1 in column 'elas')
e<- dd %>%   pivot_longer(col = "nondep_share":"share12",names_to = "elas",values_to = "share") %>% 
  mutate(
    ben_wealth = ben_loss*share/(w_share*netwealth_usd)*1e9,
    med_wealth = med_loss*share/(w_share*netwealth_usd)*1e9,
    quo_wealth = quo_loss*share/(w_share*netwealth_usd)*1e9,
    sev_wealth = sev_loss*share/(w_share*netwealth_usd)*1e9,
    perperson = case_when( ID == 1 ~ w_share*netwealth_usd/(adult_pop*.5),
                           ID == 2 ~ w_share*netwealth_usd/(adult_pop*.4),
                           ID == 3 ~ w_share*netwealth_usd/(adult_pop*.09),
                           TRUE ~    w_share*netwealth_usd/(adult_pop*.01))
  ) %>% 
  mutate(iso2 = case_when(
    iso3=="DEU" ~ "DE",
    iso3=="FRA" ~ "FR",
    iso3=="ITA" ~ "IT",
    iso3=="GBR" ~ "UK",
    TRUE ~ "US")) %>% 
  arrange(iso2)  %>% 
  ungroup()

# format data for plotting by elasticity (scenarios A, B, C)
spreader <- c(0.955,1.135,0.865,1.045)
Alist <- e %>% 
  filter(elas == "nondep_share") %>% 
  select(iso2,ID,perperson,ben_wealth:sev_wealth) %>% 
  #filter(ID == 1) %>% 
  pivot_longer(cols=ben_wealth:sev_wealth,values_to = "ScenA",names_to = "measure") %>% 
  arrange(ID,iso2) %>% 
  add_column(ctr = c(c(spreader,spreader+1,spreader+2,spreader+3,spreader+4)-0.5,
                     c(spreader,spreader+1,spreader+2,spreader+3,spreader+4)+5,
                     c(spreader,spreader+1,spreader+2,spreader+3,spreader+4)+10.5,
                     c(spreader,spreader+1,spreader+2,spreader+3,spreader+4)+16)
  )%>% 
  ungroup()

Blist <- e %>% 
  filter(elas == "share8") %>% 
  select(iso2,ID,ben_wealth:sev_wealth) %>% 
  pivot_longer(cols=ben_wealth:sev_wealth,values_to = "ScenB",names_to = "measureB") %>% 
  arrange(ID,iso2) %>% 
  rename(IDB = ID,iso2B = iso2) %>% 
  ungroup()

Clist <- e %>% 
  filter(elas == "share12") %>% 
  select(iso2,ID,ben_wealth:sev_wealth) %>% 
  pivot_longer(cols=ben_wealth:sev_wealth,values_to = "ScenC",names_to = "measureC") %>% 
  arrange(ID,iso2) %>% 
  rename(IDC = ID,iso2C = iso2) %>% 
  ungroup()

# more formatting/parameter setting for plotting
crs <- unique(e$iso2)
all <- add_column(Alist,Blist) %>% add_column(Clist)
msrs <- unique(all$measure)
alls <- all %>% group_by(iso2,ID) %>% summarize(wel = mean(perperson),pos = mean(ctr))
ctr<-0.7
ind<-0.66

# plot figure 2
pdf("figure2_zenodo.pdf",17.2/2.54,17.2/2.54*(3.9/6.6)) # using journal guidelines for width
par(mar=c(2.3,3.5,.2,.1),xpd=F)
plot(all$ctr,all$ScenA,xlim=c(1,21),ann=F,xaxt="n",yaxt="n",ylim=c(0,0.1172),bty="n",col="white")
for (i in c(0.005,0.01,0.02,0.04,0.06,0.08,.1)) {abline(h=i,lty=3,col="lightgrey")}
par(xpd=T)
#points(all$ctr,all$value)
for (i in 1:4) {
  segments(filter(all,measure==msrs[i])$ctr,filter(all,measure==msrs[i])$ScenB,filter(all,measure==msrs[i])$ctr,filter(all,measure==msrs[i])$ScenC,col=viridis(4)[5-i],lwd=0.8)
}

for (i in 1:4) {
  points(filter(all,measure==msrs[i])$ctr,filter(all,measure==msrs[i])$ScenA,col=viridis(4)[5-i],pch=19,cex=.9)
}
for (i in 1:4) {
  points(filter(all,measure==msrs[i])$ctr,filter(all,measure==msrs[i])$ScenB,col=viridis(4)[5-i],pch=17,cex=.7)
}
for (i in 1:4) {
  points(filter(all,measure==msrs[i])$ctr,filter(all,measure==msrs[i])$ScenC,col=viridis(4)[5-i],pch=15,cex=.7)
}
par(xpd=F)
abline(v=5.25,lty=2)
abline(v=5.25+5.5,lty=2)
abline(v=5.25+11,lty=2)
axis(2,at=c(0.005,0.01,0.02,0.04,0.06,0.08,.1,.13),labels=paste0(c(0.5,1,2,4,6,8,10,13),"%"),las=2,hadj=0.7,tcl=-0.36,cex.axis=0.8)
par(xpd=T)
mtext("Bottom 50%",side=3,line=-.85,adj=0.005,cex=0.8)
mtext("Middle 40%",side=3,line=-.85,at=6.7,cex=0.8)
mtext("Next 9%",side=3,line=-.85,at=11.8,cex=0.8)
mtext("Top 1%",side=3,line=-.85,at=17.22,cex=0.8)
axis(1,at=c(1:5)-0.5,labels=c("DE","FR","IT","UK","US"),cex.axis=ctr,tcl=-0.4,padj=-1.7)
axis(1,at=c(1:5)+5,labels=c("DE","FR","IT","UK","US"),cex.axis=ctr,tcl=-0.4,padj=-1.7)
axis(1,at=c(1:5)+10.5,labels=c("DE","FR","IT","UK","US"),cex.axis=ctr,tcl=-0.4,padj=-1.7)
axis(1,at=c(1:5)+16,labels=c("DE","FR","IT","UK","US"),cex.axis=ctr,tcl=-0.4,padj=-1.7)
mtext("Stranded assets as a share of net wealth",side=2,line=2.7,cex=0.8)
legend(11.53,0.11,legend=c("Severe loss","Medium (quota) loss","Low wealth bias","Medium (Fig. 1) loss","Benign loss","High wealth bias"),pch=c(19,19,2,19,19,0),col=c(viridis(4)[1:2],"black",viridis(4)[3:4],"black"),box.col = "white",pt.cex=c(1.25,1.25,.9,1.25,1.25,.9),cex=0.78,bg="white",ncol=2)
text(-1.14,-0.016,"Per adult net\nwealth in $:",cex=ind)
for(i in crs) {
  for(j in 1:2) {
    text(filter(alls,iso2==i & ID == j)$pos,-.018,paste0(round(filter(alls,iso2==i & ID == j)$wel/1e3,0),"k"),cex=ind)}}
for(i in crs) {
  for(j in 3:4) {
    text(filter(alls,iso2==i & ID == j)$pos,-0.018,paste0(round(filter(alls,iso2==i & ID == j)$wel/1e6,1),"m"),cex=ind)}}
dev.off()


# Same figure but with y-axis log scale produces Figure S4
pdf("figure_S4_zenodo.pdf",6.6,3.9)
par(mar=c(2.3,3.5,.8,.1))
plot(all$ctr,all$ScenA,xlim=c(1,21),ann=F,xaxt="n",yaxt="n",ylim=c(0.000078,0.09),bty="n",col="white",log="y")
for (i in c(0.0001,0.0005,0.001,0.005,0.01,0.02,0.04,0.06,0.09)) {abline(h=i,lty=3,col="lightgrey")}
par(xpd=T)
#points(all$ctr,all$value)
for (i in 1:4) {
  segments(filter(all,measure==msrs[i])$ctr,filter(all,measure==msrs[i])$ScenB,filter(all,measure==msrs[i])$ctr,filter(all,measure==msrs[i])$ScenC,col=viridis(4)[5-i],lwd=0.8)
}

for (i in 1:4) {
  points(filter(all,measure==msrs[i])$ctr,filter(all,measure==msrs[i])$ScenA,col=viridis(4)[5-i],pch=19,cex=.9)
}
for (i in 1:4) {
  points(filter(all,measure==msrs[i])$ctr,filter(all,measure==msrs[i])$ScenB,col=viridis(4)[5-i],pch=17,cex=.7)
}
for (i in 1:4) {
  points(filter(all,measure==msrs[i])$ctr,filter(all,measure==msrs[i])$ScenC,col=viridis(4)[5-i],pch=15,cex=.7)
}
par(xpd=F)
abline(v=5.25,lty=2)
abline(v=5.25+5.5,lty=2)
abline(v=5.25+11,lty=2)
mtext("Bottom 50%",side=3,adj=0,cex=0.8)
mtext("Middle 40%",side=3,at=6.6,cex=0.8)
mtext("Next 9%",side=3,at=11.67,cex=0.8)
mtext("Top 1%",side=3,at=17.05,cex=0.8)
axis(1,at=c(1:5)-0.5,labels=c("DE","FR","IT","UK","US"),cex.axis=ctr,tcl=-0.4,padj=-1.5)
axis(1,at=c(1:5)+5,labels=c("DE","FR","IT","UK","US"),cex.axis=ctr,tcl=-0.4,padj=-1.5)
axis(1,at=c(1:5)+10.5,labels=c("DE","FR","IT","UK","US"),cex.axis=ctr,tcl=-0.4,padj=-1.5)
axis(1,at=c(1:5)+16,labels=c("DE","FR","IT","UK","US"),cex.axis=ctr,tcl=-0.4,padj=-1.5)
mtext("Stranded assets as a share of net wealth (log scale)",side=2,line=2.7,cex=0.8)
axis(2,at=c(0.00001,0.0001,0.0005,0.001,0.005,0.01,0.02,0.04,0.06,0.09),labels=paste0(c(0,.01,0.05,0.1,0.5,1,2,4,6,9),"%"),las=2,hadj=0.7,tcl=-0.36,cex.axis=0.8)
legend("topright",legend=c("Severe loss","Medium (quota) loss","Low wealth bias","Medium (Fig. 1) loss","Benign loss","High wealth bias"),pch=c(19,19,2,19,19,0),col=c(viridis(4)[1:2],"black",viridis(4)[3:4],"black"),box.col = "white",pt.cex=c(1.25,1.25,.9,1.25,1.25,.9),cex=0.78,bg="white",ncol=2)
par(xpd=T)
text(-1.14,0.00003,"Per adult net\nwealth in $:",cex=ind)
for(i in crs) {
  for(j in 1:2) {
    text(filter(alls,iso2==i & ID == j)$pos,0.000027,paste0(round(filter(alls,iso2==i & ID == j)$wel/1e3,0),"k"),cex=ind)}}
for(i in crs) {
  for(j in 3:4) {
    text(filter(alls,iso2==i & ID == j)$pos,0.000027,paste0(round(filter(alls,iso2==i & ID == j)$wel/1e6,1),"m"),cex=ind)}}
dev.off()

